==> chromium-browser_28.0.1500.95.orig.tar.xz: chromium-browser-28.0.1500.95/src/ui/base/win/singleton_hwnd.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/base/win/singleton_hwnd.h"

#include "base/memory/singleton.h"
#include "base/message_loop.h"

namespace ui {

// static
SingletonHwnd* SingletonHwnd::GetInstance() {
  return Singleton<SingletonHwnd>::get();
}

void SingletonHwnd::AddObserver(Observer* observer) {

  if (!hwnd()) {
    if (!MessageLoop::current() ||
        MessageLoop::current()->type() != MessageLoop::TYPE_UI) {
      // Creating this window in (e.g.) a renderer inhibits shutdown on
      // Windows. See http://crbug.com/230122 and http://crbug.com/236039.
      DLOG(ERROR) << "Cannot create windows on non-UI thread!";
      return;
    }
    WindowImpl::Init(NULL, gfx::Rect());
  }
  observer_list_.AddObserver(observer);
}

void SingletonHwnd::RemoveObserver(Observer* observer) {
  if (!hwnd())
    return;
  observer_list_.RemoveObserver(observer);
}

BOOL SingletonHwnd::ProcessWindowMessage(HWND window,
                                         UINT message,
                                         WPARAM wparam,
                                         LPARAM lparam,
                                         LRESULT& result,
                                         DWORD msg_map_id) {
  FOR_EACH_OBSERVER(Observer,
                    observer_list_,
                    OnWndProc(window, message, wparam, lparam));
  return false;
}

SingletonHwnd::SingletonHwnd() {
}

SingletonHwnd::~SingletonHwnd() {
}

}  // namespace ui

==> chromium-browser_29.0.1547.65.orig.tar.xz: chromium-browser-29.0.1547.65/src/ui/base/win/singleton_hwnd.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/base/win/singleton_hwnd.h"

#include "base/memory/singleton.h"
#include "base/message_loop.h"

namespace ui {

// static
SingletonHwnd* SingletonHwnd::GetInstance() {
  return Singleton<SingletonHwnd>::get();
}

void SingletonHwnd::AddObserver(Observer* observer) {
  if (!hwnd()) {
    if (!base::MessageLoop::current() ||
        base::MessageLoop::current()->type() != base::MessageLoop::TYPE_UI) {
      // Creating this window in (e.g.) a renderer inhibits shutdown on
      // Windows. See http://crbug.com/230122 and http://crbug.com/236039.
      DLOG(ERROR) << "Cannot create windows on non-UI thread!";
      return;
    }
    WindowImpl::Init(NULL, gfx::Rect());
  }
  observer_list_.AddObserver(observer);
}

void SingletonHwnd::RemoveObserver(Observer* observer) {
  if (!hwnd())
    return;
  observer_list_.RemoveObserver(observer);
}

BOOL SingletonHwnd::ProcessWindowMessage(HWND window,
                                         UINT message,
                                         WPARAM wparam,
                                         LPARAM lparam,
                                         LRESULT& result,
                                         DWORD msg_map_id) {
  FOR_EACH_OBSERVER(Observer,
                    observer_list_,
                    OnWndProc(window, message, wparam, lparam));
  return false;
}

SingletonHwnd::SingletonHwnd() {
}

SingletonHwnd::~SingletonHwnd() {
}

}  // namespace ui
